@@ -19,11 +19,13 @@ async fn ttl_job() -> Result<()> {
 
   #[derive(Clone, Debug, Deserialize, JsonSchema)]
   pub struct WorkerParameters {
+    #[allow(dead_code)]
     source_path: String,
+    #[allow(dead_code)]
     destination_path: String,
   }
 
-  impl MessageEvent<WorkerParameters> for Worker {
+  impl McaiWorker<WorkerParameters> for Worker {
     fn get_name(&self) -> String {
       "Test Worker".to_string()
     }
